==> ejc-scientific-impl-3.0.0-20250306.080245-36-sources.jar: com/ejianc/business/scientific/sci/work/bean/WorkTimeDetailEntity.java <==
package com.ejianc.business.scientific.sci.work.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 科研管理-科研工时填报子表明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_work_time_detail")
public class WorkTimeDetailEntity extends BaseEntity {

    private static final long serialVersionUID = 3858402122324782613L;
    @TableField(value="pid")
    private Long pid; // 主表Id
    @TableField(value="user_id")
    private Long userId; // 人员主键
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="user_mobile")
    private String userMobile; // 联系方式
    @TableField(value="post_id")
    private Long postId; // 职务主键
    @TableField(value="post_name")
    private String postName; // 职务名称
    @TableField(value="professional")
    private String professional; // 职称
    @TableField(value="duty")
    private String duty; // 课题内职务
    @TableField(value="user_plan_total_hour")
    private BigDecimal userPlanTotalHour; // 计划工时(月)
    @TableField(value="user_total_hour")
    private BigDecimal userTotalHour; // 累计工时(月)
    @TableField(value="user_hour")
    private BigDecimal userHour; // 本月工时
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源单据主表Id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源单据子表Id
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserMobile() {
        return userMobile;
    }

    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getProfessional() {
        return professional;
    }

    public void setProfessional(String professional) {
        this.professional = professional;
    }
    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }
    public BigDecimal getUserPlanTotalHour() {
        return userPlanTotalHour;
    }

    public void setUserPlanTotalHour(BigDecimal userPlanTotalHour) {
        this.userPlanTotalHour = userPlanTotalHour;
    }
    public BigDecimal getUserTotalHour() {
        return userTotalHour;
    }

    public void setUserTotalHour(BigDecimal userTotalHour) {
        this.userTotalHour = userTotalHour;
    }
    public BigDecimal getUserHour() {
        return userHour;
    }

    public void setUserHour(BigDecimal userHour) {
        this.userHour = userHour;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}

==> ejc-scientific-impl-3.0.0-20250314.055155-59-sources.jar: com/ejianc/business/scientific/sci/work/bean/WorkTimeDetailEntity.java <==
package com.ejianc.business.scientific.sci.work.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 科研管理-科研工时填报子表明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_work_time_detail")
public class WorkTimeDetailEntity extends BaseEntity {

    private static final long serialVersionUID = 3858402122324782613L;
    @TableField(value="pid")
    private Long pid; // 主表Id
    @TableField(value="user_id")
    private Long userId; // 人员主键
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="user_mobile")
    private String userMobile; // 联系方式
    @TableField(value="post_id")
    private Long postId; // 职务主键
    @TableField(value="post_name")
    private String postName; // 职务名称
    @TableField(value="professional")
    private String professional; // 职称
    @TableField(value="duty")
    private String duty; // 课题内职务
    @TableField(value="user_plan_total_hour")
    private BigDecimal userPlanTotalHour; // 计划工时(月)
    @TableField(value="user_total_hour")
    private BigDecimal userTotalHour; // 累计工时(月)
    @TableField(value="user_hour")
    private BigDecimal userHour; // 本月工时
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源单据主表Id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源单据子表Id

    @TableField(value = "detail_year_month")
    private String detailYearMonth; //月份
    @TableField(value = "user_total_hour_contains_self")
    private BigDecimal userTotalHourContainsSelf; // 累计工时(月)含本期

    public String getDetailYearMonth() {
        return detailYearMonth;
    }

    public void setDetailYearMonth(String detailYearMonth) {
        this.detailYearMonth = detailYearMonth;
    }

    public BigDecimal getUserTotalHourContainsSelf() {
        return userTotalHourContainsSelf;
    }

    public void setUserTotalHourContainsSelf(BigDecimal userTotalHourContainsSelf) {
        this.userTotalHourContainsSelf = userTotalHourContainsSelf;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserMobile() {
        return userMobile;
    }

    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getProfessional() {
        return professional;
    }

    public void setProfessional(String professional) {
        this.professional = professional;
    }
    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }
    public BigDecimal getUserPlanTotalHour() {
        return userPlanTotalHour;
    }

    public void setUserPlanTotalHour(BigDecimal userPlanTotalHour) {
        this.userPlanTotalHour = userPlanTotalHour;
    }
    public BigDecimal getUserTotalHour() {
        return userTotalHour;
    }

    public void setUserTotalHour(BigDecimal userTotalHour) {
        this.userTotalHour = userTotalHour;
    }
    public BigDecimal getUserHour() {
        return userHour;
    }

    public void setUserHour(BigDecimal userHour) {
        this.userHour = userHour;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}
